#[non_exhaustive]
pub enum Event { Scale1000 { scale_1000: i32, }, Mirroring { name: Option<String>, }, AdaptiveSyncAvailable { available: WEnum<AdaptiveSyncAvailability>, }, AdaptiveSyncExt { state: WEnum<AdaptiveSyncStateExt>, }, XwaylandPrimary { state: u32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Scale1000

current scale

This events describes the scale of the head in the global compositor space multiplied by 1000 for additional precision.

It is only sent if the output is enabled.

Fields

scale_1000: i32


Mirroring

mirroring other output

This events describes that the head is mirroring another. In these cases name contains the unique name of the matching zwlr_output_head_v1. If the name is null, no head is being mirrored onto this one.

For mirrored heads the position-event is meaningless.

It is only sent if the output is enabled.

Fields



AdaptiveSyncAvailable

is adaptive_sync available for this head

This events describes if adaptive_sync is available for this head.

It is only sent if the output is enabled.

Only available since version 2 of the interface



AdaptiveSyncExt

current adaptive_sync state

This events describes the adaptive_sync state of this head.

It is only sent if the output is enabled.

Only available since version 2 of the interface



XwaylandPrimary

is this head configured as the primary for xwayland

This event describes if this head is advertised as the primary output via randr to Xwayland.

At most one output is marked primary, but it is not guaranteed that any output is marked. It is only sent if the output is enabled.

Only available since version 3 of the interface

Fields

state: u32

boolean if primary or not

Implementations

Source

impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message