pub struct ZcosmicOutputHeadV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
Output extension object
Extension to zwlr_output_head_v1.
Adds additional read-only properties.
Properties sent via this interface are applied atomically via the wlr_output_manager.done event. No guarantees are made regarding the order in which properties are sent.
See also the Event enum for this interface.
Implementations